@@ -20,8 +20,7 @@
 package javax.media;
 
 public class NotRealizedError extends MediaError {
-    public NotRealizedError(String reason)
-    {
+    public NotRealizedError(String reason) {
         super(reason);
     }
 
