@@ -19,8 +19,7 @@
 
 package javax.tv.service;
 
-public interface SIRequestor
-{
+public interface SIRequestor {
     public void notifySuccess(SIRetrievable[] result);
 
     public void notifyFailure(SIRequestFailureType reason);
